fastjsonschema: Fastest Python implementation of JSON schema
============================================================

Description
-----------

Fastest Python implementation of JSON schema

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/fastjsonschema/

